@@ -14,8 +14,9 @@
 # Copyright (c) 2019 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2020 Ram Rachum <ram@rachum.com>
-# Copyright (c) 2021 Dimitri Prybysh <dmand@yandex.ru>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Dimitri Prybysh <dmand@yandex.ru>
 # Copyright (c) 2021 David Liu <david@cs.toronto.edu>
 # Copyright (c) 2021 pre-commit-ci[bot] <bot@noreply.github.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
@@ -216,27 +217,21 @@ def infer_named_tuple(node, context=None):
         for index, name in enumerate(attributes)
     )
     fake = AstroidBuilder(AstroidManager()).string_build(
-        """
-class %(name)s(tuple):
+        f"""
+class {name}(tuple):
     __slots__ = ()
-    _fields = %(fields)r
+    _fields = {attributes!r}
     def _asdict(self):
         return self.__dict__
     @classmethod
     def _make(cls, iterable, new=tuple.__new__, len=len):
         return new(cls, iterable)
-    def _replace(self, %(replace_args)s):
+    def _replace(self, {replace_args}):
         return self
     def __getnewargs__(self):
         return tuple(self)
-%(field_defs)s
+{field_defs}
     """
-        % {
-            "name": name,
-            "fields": attributes,
-            "field_defs": field_defs,
-            "replace_args": replace_args,
-        }
     )
     class_node.locals["_asdict"] = fake.body[0].locals["_asdict"]
     class_node.locals["_make"] = fake.body[0].locals["_make"]
@@ -539,7 +534,7 @@ def infer_typing_namedtuple(node, context=None):
 
     typename = node.args[0].as_string()
     if names:
-        field_names = "({},)".format(",".join(names))
+        field_names = f"({','.join(names)},)"
     else:
         field_names = "''"
     node = extract_node(f"namedtuple({typename}, {field_names})")
