@@ -16,10 +16,11 @@
 # Copyright (c) 2018 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2018 HoverHell <hoverhell@gmail.com>
 # Copyright (c) 2020 Leandro T. C. Melo <ltcmelo@gmail.com>
-# Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
-# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
-# Copyright (c) 2021 David Liu <david@cs.toronto.edu>
+# Copyright (c) 2021 Daniël van Noord <13665637+DanielNoord@users.noreply.github.com>
 # Copyright (c) 2021 Marc Mueller <30130371+cdce8p@users.noreply.github.com>
+# Copyright (c) 2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
+# Copyright (c) 2021 Andrew Haigh <hello@nelf.in>
+# Copyright (c) 2021 David Liu <david@cs.toronto.edu>
 
 # Licensed under the LGPL: https://www.gnu.org/licenses/old-licenses/lgpl-2.1.en.html
 # For details: https://github.com/PyCQA/astroid/blob/main/LICENSE
@@ -31,7 +32,7 @@ import ast
 import functools
 import itertools
 import operator
-from typing import Any, Iterable
+from typing import Any, Callable, Dict, Iterable, Optional
 
 import wrapt
 
@@ -792,7 +793,7 @@ def infer_binop(self, context=None):
 nodes.BinOp._infer_binop = _infer_binop
 nodes.BinOp._infer = infer_binop
 
-COMPARE_OPS = {
+COMPARE_OPS: Dict[str, Callable[[Any, Any], bool]] = {
     "==": operator.eq,
     "!=": operator.ne,
     "<": operator.lt,
@@ -810,6 +811,7 @@ UNINFERABLE_OPS = {
 
 def _to_literal(node: nodes.NodeNG) -> Any:
     # Can raise SyntaxError or ValueError from ast.literal_eval
+    # Can raise AttributeError from node.as_string() as not all nodes have a visitor
     # Is this the stupidest idea or the simplest idea?
     return ast.literal_eval(node.as_string())
 
@@ -840,7 +842,7 @@ def _do_compare(
 
         try:
             left, right = _to_literal(left), _to_literal(right)
-        except (SyntaxError, ValueError):
+        except (SyntaxError, ValueError, AttributeError):
             return util.Uninferable
 
         try:
@@ -857,7 +859,9 @@ def _do_compare(
     return retval  # it was all the same value
 
 
-def _infer_compare(self: nodes.Compare, context: InferenceContext) -> Any:
+def _infer_compare(
+    self: nodes.Compare, context: Optional[InferenceContext] = None
+) -> Any:
     """Chained comparison inference logic."""
     retval = True
 
